# coding: utf-8

"""
    Kodexa

    Content Intelligence  # noqa: E501

    OpenAPI spec version: 2.0.132
    Contact: suppot@kodexa.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ContentServiceReference(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'attach_source': 'bool',
        'content_service_id': 'str',
        'content_service_version_id': 'str',
        'ref': 'str'
    }

    attribute_map = {
        'attach_source': 'attachSource',
        'content_service_id': 'contentServiceId',
        'content_service_version_id': 'contentServiceVersionId',
        'ref': 'ref'
    }

    def __init__(self, attach_source=None, content_service_id=None, content_service_version_id=None, ref=None):  # noqa: E501
        """ContentServiceReference - a model defined in Swagger"""  # noqa: E501
        self._attach_source = None
        self._content_service_id = None
        self._content_service_version_id = None
        self._ref = None
        self.discriminator = None
        if attach_source is not None:
            self.attach_source = attach_source
        if content_service_id is not None:
            self.content_service_id = content_service_id
        if content_service_version_id is not None:
            self.content_service_version_id = content_service_version_id
        if ref is not None:
            self.ref = ref

    @property
    def attach_source(self):
        """Gets the attach_source of this ContentServiceReference.  # noqa: E501


        :return: The attach_source of this ContentServiceReference.  # noqa: E501
        :rtype: bool
        """
        return self._attach_source

    @attach_source.setter
    def attach_source(self, attach_source):
        """Sets the attach_source of this ContentServiceReference.


        :param attach_source: The attach_source of this ContentServiceReference.  # noqa: E501
        :type: bool
        """

        self._attach_source = attach_source

    @property
    def content_service_id(self):
        """Gets the content_service_id of this ContentServiceReference.  # noqa: E501


        :return: The content_service_id of this ContentServiceReference.  # noqa: E501
        :rtype: str
        """
        return self._content_service_id

    @content_service_id.setter
    def content_service_id(self, content_service_id):
        """Sets the content_service_id of this ContentServiceReference.


        :param content_service_id: The content_service_id of this ContentServiceReference.  # noqa: E501
        :type: str
        """

        self._content_service_id = content_service_id

    @property
    def content_service_version_id(self):
        """Gets the content_service_version_id of this ContentServiceReference.  # noqa: E501


        :return: The content_service_version_id of this ContentServiceReference.  # noqa: E501
        :rtype: str
        """
        return self._content_service_version_id

    @content_service_version_id.setter
    def content_service_version_id(self, content_service_version_id):
        """Sets the content_service_version_id of this ContentServiceReference.


        :param content_service_version_id: The content_service_version_id of this ContentServiceReference.  # noqa: E501
        :type: str
        """

        self._content_service_version_id = content_service_version_id

    @property
    def ref(self):
        """Gets the ref of this ContentServiceReference.  # noqa: E501


        :return: The ref of this ContentServiceReference.  # noqa: E501
        :rtype: str
        """
        return self._ref

    @ref.setter
    def ref(self, ref):
        """Sets the ref of this ContentServiceReference.


        :param ref: The ref of this ContentServiceReference.  # noqa: E501
        :type: str
        """

        self._ref = ref

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ContentServiceReference, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ContentServiceReference):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
