# coding: utf-8

"""
    Kodexa

    Content Intelligence  # noqa: E501

    OpenAPI spec version: 2.0.132
    Contact: suppot@kodexa.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class PipelineStepMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'options': 'object',
        'organization_slug': 'str',
        'slug': 'str'
    }

    attribute_map = {
        'name': 'name',
        'options': 'options',
        'organization_slug': 'organizationSlug',
        'slug': 'slug'
    }

    def __init__(self, name=None, options=None, organization_slug=None, slug=None):  # noqa: E501
        """PipelineStepMetadata - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._options = None
        self._organization_slug = None
        self._slug = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if options is not None:
            self.options = options
        if organization_slug is not None:
            self.organization_slug = organization_slug
        if slug is not None:
            self.slug = slug

    @property
    def name(self):
        """Gets the name of this PipelineStepMetadata.  # noqa: E501


        :return: The name of this PipelineStepMetadata.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PipelineStepMetadata.


        :param name: The name of this PipelineStepMetadata.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def options(self):
        """Gets the options of this PipelineStepMetadata.  # noqa: E501


        :return: The options of this PipelineStepMetadata.  # noqa: E501
        :rtype: object
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this PipelineStepMetadata.


        :param options: The options of this PipelineStepMetadata.  # noqa: E501
        :type: object
        """

        self._options = options

    @property
    def organization_slug(self):
        """Gets the organization_slug of this PipelineStepMetadata.  # noqa: E501


        :return: The organization_slug of this PipelineStepMetadata.  # noqa: E501
        :rtype: str
        """
        return self._organization_slug

    @organization_slug.setter
    def organization_slug(self, organization_slug):
        """Sets the organization_slug of this PipelineStepMetadata.


        :param organization_slug: The organization_slug of this PipelineStepMetadata.  # noqa: E501
        :type: str
        """

        self._organization_slug = organization_slug

    @property
    def slug(self):
        """Gets the slug of this PipelineStepMetadata.  # noqa: E501


        :return: The slug of this PipelineStepMetadata.  # noqa: E501
        :rtype: str
        """
        return self._slug

    @slug.setter
    def slug(self, slug):
        """Sets the slug of this PipelineStepMetadata.


        :param slug: The slug of this PipelineStepMetadata.  # noqa: E501
        :type: str
        """

        self._slug = slug

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PipelineStepMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PipelineStepMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
