# coding: utf-8

"""
    Kodexa

    Content Intelligence  # noqa: E501

    OpenAPI spec version: 2.0.132
    Contact: suppot@kodexa.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class OrganizationDashboard(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'pipeline_count': 'int',
        'request_count': 'int',
        'service_count': 'int',
        'user_count': 'int'
    }

    attribute_map = {
        'pipeline_count': 'pipelineCount',
        'request_count': 'requestCount',
        'service_count': 'serviceCount',
        'user_count': 'userCount'
    }

    def __init__(self, pipeline_count=None, request_count=None, service_count=None, user_count=None):  # noqa: E501
        """OrganizationDashboard - a model defined in Swagger"""  # noqa: E501
        self._pipeline_count = None
        self._request_count = None
        self._service_count = None
        self._user_count = None
        self.discriminator = None
        if pipeline_count is not None:
            self.pipeline_count = pipeline_count
        if request_count is not None:
            self.request_count = request_count
        if service_count is not None:
            self.service_count = service_count
        if user_count is not None:
            self.user_count = user_count

    @property
    def pipeline_count(self):
        """Gets the pipeline_count of this OrganizationDashboard.  # noqa: E501


        :return: The pipeline_count of this OrganizationDashboard.  # noqa: E501
        :rtype: int
        """
        return self._pipeline_count

    @pipeline_count.setter
    def pipeline_count(self, pipeline_count):
        """Sets the pipeline_count of this OrganizationDashboard.


        :param pipeline_count: The pipeline_count of this OrganizationDashboard.  # noqa: E501
        :type: int
        """

        self._pipeline_count = pipeline_count

    @property
    def request_count(self):
        """Gets the request_count of this OrganizationDashboard.  # noqa: E501


        :return: The request_count of this OrganizationDashboard.  # noqa: E501
        :rtype: int
        """
        return self._request_count

    @request_count.setter
    def request_count(self, request_count):
        """Sets the request_count of this OrganizationDashboard.


        :param request_count: The request_count of this OrganizationDashboard.  # noqa: E501
        :type: int
        """

        self._request_count = request_count

    @property
    def service_count(self):
        """Gets the service_count of this OrganizationDashboard.  # noqa: E501


        :return: The service_count of this OrganizationDashboard.  # noqa: E501
        :rtype: int
        """
        return self._service_count

    @service_count.setter
    def service_count(self, service_count):
        """Sets the service_count of this OrganizationDashboard.


        :param service_count: The service_count of this OrganizationDashboard.  # noqa: E501
        :type: int
        """

        self._service_count = service_count

    @property
    def user_count(self):
        """Gets the user_count of this OrganizationDashboard.  # noqa: E501


        :return: The user_count of this OrganizationDashboard.  # noqa: E501
        :rtype: int
        """
        return self._user_count

    @user_count.setter
    def user_count(self, user_count):
        """Sets the user_count of this OrganizationDashboard.


        :param user_count: The user_count of this OrganizationDashboard.  # noqa: E501
        :type: int
        """

        self._user_count = user_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OrganizationDashboard, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrganizationDashboard):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
