# coding: utf-8

"""
    Kodexa

    Content Intelligence  # noqa: E501

    OpenAPI spec version: 2.0.132
    Contact: suppot@kodexa.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from kodexa_cloud.api_client import ApiClient


class ContentServicesEndpointControllerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def process_using_get1(self, organization_slug, service_slug, **kwargs):  # noqa: E501
        """process  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_using_get1(organization_slug, service_slug, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_slug: organizationSlug (required)
        :param str service_slug: serviceSlug (required)
        :return: ContentServiceVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.process_using_get1_with_http_info(organization_slug, service_slug, **kwargs)  # noqa: E501
        else:
            (data) = self.process_using_get1_with_http_info(organization_slug, service_slug, **kwargs)  # noqa: E501
            return data

    def process_using_get1_with_http_info(self, organization_slug, service_slug, **kwargs):  # noqa: E501
        """process  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_using_get1_with_http_info(organization_slug, service_slug, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_slug: organizationSlug (required)
        :param str service_slug: serviceSlug (required)
        :return: ContentServiceVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['organization_slug', 'service_slug']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method process_using_get1" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'organization_slug' is set
        if ('organization_slug' not in params or
                params['organization_slug'] is None):
            raise ValueError("Missing the required parameter `organization_slug` when calling `process_using_get1`")  # noqa: E501
        # verify the required parameter 'service_slug' is set
        if ('service_slug' not in params or
                params['service_slug'] is None):
            raise ValueError("Missing the required parameter `service_slug` when calling `process_using_get1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'organization_slug' in params:
            path_params['organizationSlug'] = params['organization_slug']  # noqa: E501
        if 'service_slug' in params:
            path_params['serviceSlug'] = params['service_slug']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/processing/services/{organizationSlug}/{serviceSlug}/latest', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ContentServiceVersion',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
