# coding: utf-8

"""
    Kodexa

    Content Intelligence  # noqa: E501

    OpenAPI spec version: 2.0.132
    Contact: suppot@kodexa.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ExceptionDetails(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'error_message': 'str',
        'error_type': 'str',
        'executed_version': 'str',
        'help': 'str',
        'message': 'str',
        'stack_trace': 'list[object]',
        'status_code': 'int'
    }

    attribute_map = {
        'error_message': 'errorMessage',
        'error_type': 'errorType',
        'executed_version': 'executedVersion',
        'help': 'help',
        'message': 'message',
        'stack_trace': 'stackTrace',
        'status_code': 'statusCode'
    }

    def __init__(self, error_message=None, error_type=None, executed_version=None, help=None, message=None, stack_trace=None, status_code=None):  # noqa: E501
        """ExceptionDetails - a model defined in Swagger"""  # noqa: E501
        self._error_message = None
        self._error_type = None
        self._executed_version = None
        self._help = None
        self._message = None
        self._stack_trace = None
        self._status_code = None
        self.discriminator = None
        if error_message is not None:
            self.error_message = error_message
        if error_type is not None:
            self.error_type = error_type
        if executed_version is not None:
            self.executed_version = executed_version
        if help is not None:
            self.help = help
        if message is not None:
            self.message = message
        if stack_trace is not None:
            self.stack_trace = stack_trace
        if status_code is not None:
            self.status_code = status_code

    @property
    def error_message(self):
        """Gets the error_message of this ExceptionDetails.  # noqa: E501


        :return: The error_message of this ExceptionDetails.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this ExceptionDetails.


        :param error_message: The error_message of this ExceptionDetails.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    @property
    def error_type(self):
        """Gets the error_type of this ExceptionDetails.  # noqa: E501


        :return: The error_type of this ExceptionDetails.  # noqa: E501
        :rtype: str
        """
        return self._error_type

    @error_type.setter
    def error_type(self, error_type):
        """Sets the error_type of this ExceptionDetails.


        :param error_type: The error_type of this ExceptionDetails.  # noqa: E501
        :type: str
        """

        self._error_type = error_type

    @property
    def executed_version(self):
        """Gets the executed_version of this ExceptionDetails.  # noqa: E501


        :return: The executed_version of this ExceptionDetails.  # noqa: E501
        :rtype: str
        """
        return self._executed_version

    @executed_version.setter
    def executed_version(self, executed_version):
        """Sets the executed_version of this ExceptionDetails.


        :param executed_version: The executed_version of this ExceptionDetails.  # noqa: E501
        :type: str
        """

        self._executed_version = executed_version

    @property
    def help(self):
        """Gets the help of this ExceptionDetails.  # noqa: E501


        :return: The help of this ExceptionDetails.  # noqa: E501
        :rtype: str
        """
        return self._help

    @help.setter
    def help(self, help):
        """Sets the help of this ExceptionDetails.


        :param help: The help of this ExceptionDetails.  # noqa: E501
        :type: str
        """

        self._help = help

    @property
    def message(self):
        """Gets the message of this ExceptionDetails.  # noqa: E501


        :return: The message of this ExceptionDetails.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ExceptionDetails.


        :param message: The message of this ExceptionDetails.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def stack_trace(self):
        """Gets the stack_trace of this ExceptionDetails.  # noqa: E501


        :return: The stack_trace of this ExceptionDetails.  # noqa: E501
        :rtype: list[object]
        """
        return self._stack_trace

    @stack_trace.setter
    def stack_trace(self, stack_trace):
        """Sets the stack_trace of this ExceptionDetails.


        :param stack_trace: The stack_trace of this ExceptionDetails.  # noqa: E501
        :type: list[object]
        """

        self._stack_trace = stack_trace

    @property
    def status_code(self):
        """Gets the status_code of this ExceptionDetails.  # noqa: E501


        :return: The status_code of this ExceptionDetails.  # noqa: E501
        :rtype: int
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """Sets the status_code of this ExceptionDetails.


        :param status_code: The status_code of this ExceptionDetails.  # noqa: E501
        :type: int
        """

        self._status_code = status_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ExceptionDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExceptionDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
